==> naive-ui-2.24.0.tgz: package/es/carousel/src/CarouselItem.js <==
import { h, defineComponent, renderSlot, inject, computed, ref, onMounted, onBeforeUnmount } from 'vue';
import { useConfig } from '../../_mixins';
import { throwError } from '../../_utils';
import { carouselMethodsInjectionKey } from './interface';
export default defineComponent({
    name: 'CarouselItem',
    setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const NCarousel = inject(carouselMethodsInjectionKey, null);
        if (!NCarousel) {
            throwError('carousel-item', '`n-carousel-item` must be placed inside `n-carousel`.');
        }
        const selfElRef = ref();
        const isPrevRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return Boolean(selfEl && NCarousel.isPrev(selfEl));
        });
        const isNextRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return Boolean(selfEl && NCarousel.isNext(selfEl));
        });
        const isActiveRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return Boolean(selfEl && NCarousel.isActive(selfEl));
        });
        const styleRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return selfEl && NCarousel.getSlideStyle(selfEl);
        });
        const indexRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return selfEl && NCarousel.getSlideIndex(selfEl);
        });
        function handleClick(e) {
            const { value: index } = indexRef;
            if (index !== undefined) {
                NCarousel === null || NCarousel === void 0 ? void 0 : NCarousel.onCarouselItemClick(index);
            }
        }
        onMounted(() => NCarousel.addSlide(selfElRef.value));
        onBeforeUnmount(() => {
            NCarousel.removeSlide(selfElRef.value);
        });
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            selfElRef,
            isPrev: isPrevRef,
            isNext: isNextRef,
            isActive: isActiveRef,
            index: indexRef,
            style: styleRef,
            handleClick
        };
    },
    render() {
        const { $slots: slots, mergedClsPrefix, isPrev, isNext, isActive, index, style } = this;
        const className = [
            `${mergedClsPrefix}-carousel__slide`,
            {
                [`${mergedClsPrefix}-carousel__slide--current`]: isActive,
                [`${mergedClsPrefix}-carousel__slide--prev`]: isPrev,
                [`${mergedClsPrefix}-carousel__slide--next`]: isNext
            }
        ];
        return (h("div", { ref: 'selfElRef', class: className, role: 'option', tabindex: "-1", "data-index": index, "aria-hidden": !isActive, style: style, onClick: this.handleClick }, renderSlot(slots, 'default', {
            isPrev,
            isNext,
            isActive,
            index
        })));
    }
});

==> naive-ui-2.24.5.tgz: package/es/carousel/src/CarouselItem.js <==
import { h, defineComponent, inject, computed, ref, onMounted, onBeforeUnmount } from 'vue';
import { useConfig } from '../../_mixins';
import { throwError } from '../../_utils';
import { carouselMethodsInjectionKey } from './interface';
export default defineComponent({
    name: 'CarouselItem',
    setup(props) {
        const { mergedClsPrefixRef } = useConfig(props);
        const NCarousel = inject(carouselMethodsInjectionKey, null);
        if (!NCarousel) {
            throwError('carousel-item', '`n-carousel-item` must be placed inside `n-carousel`.');
        }
        const selfElRef = ref();
        const isPrevRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return Boolean(selfEl && NCarousel.isPrev(selfEl));
        });
        const isNextRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return Boolean(selfEl && NCarousel.isNext(selfEl));
        });
        const isActiveRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return Boolean(selfEl && NCarousel.isActive(selfEl));
        });
        const styleRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return selfEl && NCarousel.getSlideStyle(selfEl);
        });
        const indexRef = computed(() => {
            const { value: selfEl } = selfElRef;
            return selfEl && NCarousel.getSlideIndex(selfEl);
        });
        function handleClick(event) {
            const { value: index } = indexRef;
            if (index !== undefined) {
                NCarousel === null || NCarousel === void 0 ? void 0 : NCarousel.onCarouselItemClick(index, event);
            }
        }
        onMounted(() => NCarousel.addSlide(selfElRef.value));
        onBeforeUnmount(() => {
            NCarousel.removeSlide(selfElRef.value);
        });
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            selfElRef,
            isPrev: isPrevRef,
            isNext: isNextRef,
            isActive: isActiveRef,
            index: indexRef,
            style: styleRef,
            handleClick
        };
    },
    render() {
        var _a;
        const { $slots: slots, mergedClsPrefix, isPrev, isNext, isActive, index, style } = this;
        const className = [
            `${mergedClsPrefix}-carousel__slide`,
            {
                [`${mergedClsPrefix}-carousel__slide--current`]: isActive,
                [`${mergedClsPrefix}-carousel__slide--prev`]: isPrev,
                [`${mergedClsPrefix}-carousel__slide--next`]: isNext
            }
        ];
        return (h("div", { ref: "selfElRef", class: className, role: "option", tabindex: "-1", "data-index": index, "aria-hidden": !isActive, style: style, 
            // @ts-expect-error
            onClickCapture: this.handleClick }, (_a = slots.default) === null || _a === void 0 ? void 0 : _a.call(slots, {
            isPrev,
            isNext,
            isActive,
            index
        })));
    }
});
